@@ -100,7 +100,7 @@ matchedDiagnostics <- function(cohort,
       estimates = "density")
 
   cli::cli_bullets(c("*" = "{.strong Running large scale characterisation}"))
-  results[[paste0("lsc_", workingCohortName)]] <- CohortCharacteristics::summariseLargeScaleCharacteristics(
+  results[[paste0("lsc_standard_source_", workingCohortName)]] <- CohortCharacteristics::summariseLargeScaleCharacteristics(
     cohort = cdm[[tempCohortTable]],
     window = list(c(-Inf, -1), c(-Inf, -366), c(-365, -31),
                   c(-30, -1), c(0, 0),
@@ -114,6 +114,21 @@ matchedDiagnostics <- function(cohort,
     includeSource = TRUE,
     excludedCodes = NULL
   )
+
+  results[[paste0("lsc_standard_", workingCohortName)]] <- CohortCharacteristics::summariseLargeScaleCharacteristics(
+    cohort = cdm[[tempCohortTable]],
+    window = list(c(-Inf, -1), c(-Inf, -366), c(-365, -31),
+                  c(-30, -1), c(0, 0),
+                  c(1, 30), c(31, 365),
+                  c(366, Inf), c(1, Inf)),
+    eventInWindow = c("condition_occurrence", "visit_occurrence",
+                      "measurement", "procedure_occurrence",
+                      "observation"),
+    episodeInWindow = c("drug_exposure"),
+    minimumFrequency = 0.0005,
+    includeSource = FALSE,
+    excludedCodes = NULL
+  )
   }
 
   omopgenerics::dropTable(cdm, dplyr::starts_with(prefix))
